Match

Struct Match 

pub struct Match {
    pub pattern_id: usize,
    pub start: usize,
    pub end: usize,
}
One occurrence reported by the automaton.

The matched substring is text[start..end]; end is exclusive and equals start + len where len is the length of pattern pattern_id.

Fields

pattern_id: usize

Index of the matched pattern in the original patterns slice.

start: usize

Start byte offset of the occurrence within the scanned text.

end: usize

End byte offset (exclusive) of the occurrence within the scanned text.