Memm

Struct Memm 

pub struct Memm {
    pub n_labels: usize,
    pub n_features: usize,
    pub weights: Vec<f64>,
    pub start_label: usize,
}
Maximum-entropy Markov model: per-current-label softmax conditioned on the previous label and the current feature vector.

  • weights[prev * n_labels * n_features + cur * n_features + f] — weight of feature f for the transition prev -> cur.

Fields

n_labels: usizen_features: usizeweights: Vec<f64>start_label: usize

Implementations

Source

impl Memm

pub fn zeros(n_labels: usize, n_features: usize) -> SeqResult<Self>

Zero-initialised MEMM.

pub fn class_probs(&self, prev: usize, x: &[f64]) -> SeqResult<Vec<f64>>

Compute p(cur | prev, x) for all cur given prev and x.

pub fn decode_greedy(&self, x: &[f64]) -> SeqResult<Vec<usize>>

Greedy decode: pick argmax at each step.

pub fn decode_beam(&self, x: &[f64], beam: usize) -> SeqResult<Vec<usize>>

Beam decode of width beam.