pub struct BertScore {
pub precision: f64,
pub recall: f64,
pub f1: f64,
}Expand description
Precision / recall / F1 triple produced by BERTScore.
Fields
precision: f64Precision: how well each candidate token is covered by the reference.
recall: f64Recall: how well each reference token is covered by the candidate.
f1: f64Harmonic mean of precision and recall.